@@ -99,6 +99,11 @@ class BaseSpider(Thread):
 
         # 导入一次连接，使得连接创建
         from palp import conn
+        if settings.SPIDER_TYPE == 2:
+            if conn.redis_conn is None:
+                raise ConnectionError('redis 未连接！')
+            else:
+                conn.redis_conn.info()
 
     def start_requests(self) -> None:
         """
